@@ -500,7 +500,8 @@ def clone(source, destination, verbose):
 def update(verbose, base, warn, shallow):
     """Incremental import of git into darcs.
 
-    By default it imports from the first commit or the last checkpoint.
+    By default it imports a shallow copy (the current commit). Use `--no-shallow` to
+    import the complete history.
     """
     setup(warn, verbose=verbose)
     if not Path(".git").exists():
@@ -521,9 +522,9 @@ def update(verbose, base, warn, shallow):
             rbase = base
             if shallow is True:
                 print("Found base-option, ignoring shallow-option")
-            if shallow is False:
-                do_one = False
-                rbase = get_base()
+        if shallow is False:
+            do_one = False
+            rbase = get_base()
     if _isatty:
         _thread = Thread(target=handle_shutdown, daemon=True)
         _thread.start()
